"""
   DWF Python Example 7
   Author:  Digilent, Inc.
   Revision: 10/17/2013

   Requires:                       
       Python 2.7
"""

from ctypes import *
from dwfconstants import *
import time
import sys

if sys.platform.startswith("win"):
    dwf = cdll.dwf
elif sys.platform.startswith("darwin"):
    dwf = cdll.LoadLibrary("libdwf.dylib")
else:
    dwf = cdll.LoadLibrary("libdwf.so")

#declare ctype variables
hdwf = c_int()
IsEnabled = c_bool()
deviceVoltage = c_double()
deviceCurrent = c_double()
deviceTemperature = c_double()


#print DWF version
version = create_string_buffer(16)
dwf.FDwfGetVersion(version)
print "DWF Version: "+version.value

#open device
print "Opening first device"
dwf.FDwfDeviceOpen(c_int(-1), byref(hdwf))

if hdwf.value == hdwfNone.value:
    print "failed to open device"
    quit()

print "Preparing to monitor Voltage, Current, Temp..."

#monitor voltage, current, temperature
#60 times, once per second
for i in range(1, 60):
    # wait between readings; the update rate is approximately 1Hz
    time.sleep(1)
    # fetch analog IO status from device
    dwf.FDwfAnalogIOStatus(hdwf)
    # get system monitor readings
    dwf.FDwfAnalogIOChannelNodeStatus(hdwf, c_int(2), c_int(0), byref(deviceVoltage))
    dwf.FDwfAnalogIOChannelNodeStatus(hdwf, c_int(2), c_int(1), byref(deviceCurrent))
    dwf.FDwfAnalogIOChannelNodeStatus(hdwf, c_int(2), c_int(2), byref(deviceTemperature))
    print "Device USB supply voltage: " + str(deviceVoltage.value) + "V"
    print "Device USB supply current: " + str(deviceCurrent.value) + "A"
    print "Device temperature: " + str(deviceTemperature.value) + "C"
#close the device
dwf.FDwfDeviceCloseAll()
